@@ -282,6 +282,7 @@ mac_duplicate (const PedDisk* disk)
 	PedDisk*	new_disk;
 	MacDiskData*	new_mac_data;
 	MacDiskData*	old_mac_data = (MacDiskData*) disk->disk_specific;
+	PedPartition*	partition_map;
        
 	new_disk = ped_disk_new_fresh (disk->dev, &mac_disk_type);
 	if (!new_disk)
@@ -289,6 +290,13 @@ mac_duplicate (const PedDisk* disk)
 
 	new_mac_data = (MacDiskData*) new_disk->disk_specific;
 
+	/* remove the partition map partition - it will be duplicated
+	 * later.
+	 */
+	partition_map = ped_disk_get_partition_by_sector (new_disk, 1);
+	PED_ASSERT (partition_map != NULL, return 0);
+	ped_disk_remove_partition (new_disk, partition_map);
+
 	/* ugly, but C is ugly :p */
 	memcpy (new_mac_data, old_mac_data, sizeof (MacDiskData));
 	return new_disk;
