@@ -427,7 +427,7 @@ _construct_prompt (const char* head, const char* def,
 				free (text);
 			}
 		}
-		realloc_and_cat (prompt, "? ");
+		prompt = realloc_and_cat (prompt, "? ");
 	} else if (def) {
 		if (strlen (prompt))
 			prompt = realloc_and_cat (prompt, "  ");
@@ -957,102 +957,10 @@ help_msg ()
 	exit (0);
 }
 
-/* we need a CHS warning if there is a DOS partition table with a FAT
- * partition(s) without the LBA flag set
- */
-static int
-_need_chs_warning (PedDevice* dev)
-{
-#if defined (__i386__)
-	PedDisk*	disk;
-	PedPartition*	walk;
-	int		has_non_lba_fat;
-
-	disk = ped_disk_new (dev);
-	if (!disk)
-		return 0;
-
-	if (strcmp (disk->type->name, "msdos")) {
-		ped_disk_destroy (disk);
-		return 0;
-	}
-
-	has_non_lba_fat = 0;
-	for (walk = ped_disk_next_partition (disk, NULL); walk;
-	     walk = ped_disk_next_partition (disk, walk)) {
-		if (!ped_partition_is_active (walk))
-			continue;
-		if (!walk->fs_type)
-			continue;
-
-		if (!strcmp(walk->fs_type->name, "FAT")
-		    && !ped_partition_get_flag (walk, PED_PARTITION_LBA))
-			has_non_lba_fat = 1;
-	}
-
-	ped_disk_destroy (disk);
-	return has_non_lba_fat;
-#else
-	return 0;
-#endif
-}
-
-/* if we need to scare users about CHS stuff, do it...
- */
-static void
-_do_chs_check (PedDevice* dev)
-{
-#if defined (__i386__)
-	PedExceptionType	ex_type;
-	char*			warning_msg;
-
-	if (_need_chs_warning (dev)) {
-		ex_type = PED_EXCEPTION_WARNING;
-		warning_msg = _("  You have Windows FAT partition(s) that are "
-				"not using LBA.  If your BIOS supports LBA, "
-				"then you should switch to LBA by setting the "
-				"LBA flag on all FAT partitions.  Otherwise, "
-				"make sure the operating system and the BIOS "
-				"have the same geometry before resizing any "
-				"FAT partitions.");
-	} else {
-		ex_type = PED_EXCEPTION_INFORMATION;
-		warning_msg = "";
-	}
-
-	/* already been subjected to a rant */
-	if (!dev->geom_known)
-		return;
-
-	if (dev->cylinders > 1024)
-		ped_exception_throw (
-			ex_type,
-			PED_EXCEPTION_OK,
-		_("The operating system thinks the geometry on %s is "
-		  "%d/%d/%d.  Therefore, cylinder 1024 ends at %.3fM.%s"),
-			dev->path,
-			dev->cylinders, dev->heads, dev->sectors,
-			(1024 * dev->heads * dev->sectors - 1) / 2 / 1024.0,
-			warning_msg);
-	else
-		ped_exception_throw (
-			ex_type,
-			PED_EXCEPTION_OK,
-		_("The operating system thinks the geometry on %s is "
-		  "%d/%d/%d.%s"),
-			dev->path,
-			dev->cylinders, dev->heads, dev->sectors,
-			warning_msg);
-#endif
-}
-
 void
 print_using_dev (PedDevice* dev)
 {
 	printf (_("Using %s\n"), dev->path);
-	if (dev->type != PED_DEVICE_UNKNOWN
-	    && dev->type != PED_DEVICE_FILE)
-		_do_chs_check (dev);
 }
 
 int
